==> yndenz-base-theme-2.0.4.6-08882b.zip: archive.php <==
<?php

$title = null;
if (is_date()) {
    if (is_category('nieuws')) {
        $title = _e('Nieuws', 'base-theme') . single_month_title(' ', false);
    } else {
        $title = trim(single_month_title(' ', false));
    }
} else if (is_category()) {
    if (is_category('nieuws')) {
        $title = __('Laatste nieuws', 'base-theme');
    } else {
        $title = get_the_category();
    }
} else if (is_tag()) {
    $title = single_tag_title('', false);
}

get_header();
?>

<?php
if (class_exists('\\yndenz\\Modules\\Banner\\Banner')) :
    $banner = new \yndenz\Modules\Banner\Banner();
    $banner->initialize($title);
    $banner->display();
endif;
?>

    <div class="content">

        <?php get_template_part('partials/breadcrumb-cta-bar'); ?>

        <section role="main" class="container">
            <header>
                <h1 class="<?php echo isset($banner) && $banner->isTitleIncluded() ? 'sr-only' : ''; ?>">
                    <?php echo $title; ?>
                </h1>
            </header>

            <?php if (is_category('nieuws') || is_tag()) : ?>
                <div class="filters">
                    <?php dynamic_sidebar('archive-news-sidebar'); ?>
                </div>
            <?php endif; ?>

            <?php if (function_exists('wp_pagenavi')) : ?>
                <div class="pagination-wrapper">
                    <?php wp_pagenavi(); ?>
                </div>
            <?php endif; ?>

            <?php get_template_part('partials/loop', 'posts'); ?>

            <?php if (function_exists('wp_pagenavi')) : ?>
                <div class="pagination-wrapper">
                    <?php wp_pagenavi(); ?>
                </div>
            <?php endif; ?>
        </section>

    </div>

<?php get_footer(); ?>

==> yndenz-base-theme-2.1.2.17-ba0059.zip: archive.php <==
<?php

$title = null;
if (is_date()) {
    if (is_category('nieuws')) {
        $title = _e('Nieuws', 'base-theme') . single_month_title(' ', false);
    } else {
        $title = trim(single_month_title(' ', false));
    }
} else if (is_category()) {
    $title = single_cat_title('', false);
} else if (is_tag()) {
    $title = single_tag_title('', false);
}

get_header();
?>

<?php
if (class_exists('\\yndenz\\Modules\\Banner\\Banner')) :
    $banner = new \yndenz\Modules\Banner\Banner();
    $banner->initialize($title);
    $banner->display();
endif;
?>

    <div class="ybt-content">

        <?php get_template_part('partials/breadcrumb-cta-bar'); ?>

        <section role="main" class="container">
            <header class="page-header<?php echo isset($banner) && $banner->isTitleIncluded() ? ' sr-only' : ''; ?>">
                <h1>
                    <?php echo $title; ?>
                </h1>
            </header>

            <?php echo category_description(); ?>

            <?php if (is_date() || is_post_type_archive(['post']) || is_category() || is_tag()) : ?>
                <div class="ybt-archive-filters">
                    <?php dynamic_sidebar('archive-news-sidebar'); ?>
                </div>
            <?php endif; ?>

            <?php if (function_exists('wp_pagenavi')) : ?>
                <div class="ybt-pagination">
                    <?php wp_pagenavi(); ?>
                </div>
            <?php endif; ?>

            <?php get_template_part('partials/loop', 'posts'); ?>

            <?php if (function_exists('wp_pagenavi')) : ?>
                <div class="ybt-pagination">
                    <?php wp_pagenavi(); ?>
                </div>
            <?php endif; ?>
        </section>

    </div>

<?php get_footer(); ?>
